<?php

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Field\Models\Field;
use EventPortal\Enums\Status;

/** @var \Illuminate\Database\Eloquent\Factory $factory */

$factory->define(Event::class, static function () {
    return [
        'status' => Status::DRAFT(),
    ];
});

$factory->state(Event::class, 'default-data', static function () {
    return [];
});

$factory->afterCreatingState(Event::class, 'default-data', static function ($event) {

    $section = factory(Field::class)
        ->state('Section')
        ->create([
            'model_id' => $event->id,
            'model_type' => get_class($event),
        ]);

    $name = factory(Field::class)
        ->states('TextInput')
        ->create([
            'model_id' => $event->id,
            'model_type' => get_class($event),
            'section_id' => $section->id,
            'label' => 'Event Name',
            'name' => 'name',
        ]);

    $date = factory(Field::class)
        ->states('TextInput')
        ->create([
            'model_id' => $event->id,
            'model_type' => get_class($event),
            'section_id' => $section->id,
            'label' => 'Event Date',
            'name' => 'date',
        ]);

    $type = factory(Field::class)
        ->states('Select')
        ->create([
            'model_id' => $event->id,
            'model_type' => get_class($event),
            'section_id' => $section->id,
            'label' => 'Event Type',
            'name' => 'type',
            'data' => [
                'options' => [
                    [
                        'label' => 'Single',
                        'value' => 'single',
                    ],
                    [
                        'label' => 'Seminar',
                        'value' => 'seminar',
                    ]
                ]
            ]
        ]);

    $status = factory(Field::class)
        ->states('Select')
        ->create([
            'model_id' => $event->id,
            'model_type' => get_class($event),
            'section_id' => $section->id,
            'label' => 'Event Status',
            'name' => 'status',
            'data' => [
                'options' => [
                    [
                        'label' => 'Draft',
                        'value' => 'draft',
                    ],
                    [
                        'label' => 'Published',
                        'value' => 'published',
                    ]
                ]
            ]
        ]);
});
