<?php

namespace EventPortal\Concerns;

use EventPortal\Contracts\HasFields as HasFieldsContract;
use EventPortal\Domain\Field\Actions\InitialiseFields;
use EventPortal\Domain\Field\Models\Field;
use EventPortal\Domain\Response\Actions\SaveToFields;
use Illuminate\Database\Eloquent\Relations\MorphMany;

trait HasFields
{
    public function sections(): MorphMany
    {
        return $this->fields()->onlySections();
    }

    public function fields(): MorphMany
    {
        return $this->morphMany(Field::class, 'model');
    }

    public function initialiseFields(array $content): HasFieldsContract
    {
        app(InitialiseFields::class)->execute($content, $this);

        return $this;
    }

    public function saveToFields(array $data): HasFieldsContract
    {
        app(SaveToFields::class)->execute($this, $data);

        return $this->fresh();
    }

    /** @return mixed **/
    public function getValueAttribute()
    {
        return $this->response->data->get('value');
    }
}
