<?php

namespace EventPortal\Domain\Table;

use Illuminate\Contracts\Pagination\LengthAwarePaginator;
use Illuminate\Support\Arr;
use Illuminate\Support\Collection;

class Table
{
    /** @var array */
    public $columns = [];

    /** @var array */
    public $allColumns = [];

    /** @var array */
    public $data = [];

    /** @var GroupedActions */
    public $globalActions;

    /** @var array */
    public $filterFields = [];

    public $metadata = [
        'filters' => [],
        'sortBy' => [],
        'totalItems' => 0,
        'pageCount' => 0,
        'pageNum' => 1,
        'pageSize' => 0,
        'columns' => [],
    ];

    public static function make(): self
    {
        return new self();
    }

    public function defaultPageSize(string $pageSize): self
    {
        $this->metadata['pageSize'] = $pageSize;

        return $this;
    }

    public function withColumns(Collection $columns): self
    {
        $this->columns = $columns;

        $this->columns[] = [
            'label' => '',
            'key' => 'action',
            'type' => 'actionObject',
        ];

        $this->metadata['columns'] = Arr::pluck($this->columns, 'key');

        return $this;
    }

    public function withAllColumns(Collection $columns): self
    {
        $this->allColumns = $columns;

        return $this;
    }

    public function withFiltersFields(Collection $filterFields): self
    {
        $this->filterFields = $filterFields;

        return $this;
    }

    public function currentFilters(Collection $filters): self
    {
        $this->metadata['filters'] = $filters
            ->map(static function ($value, $key) {
                return [
                    'id' => $key,
                    'value' => $value,
                ];
            })
            ->values()
            ->toArray();

        return $this;
    }

    public function currentQuery(?string $query): self
    {
        if ($query !== null) {
            $this->metadata['query'] = $query;
        }

        return $this;
    }

    public function withGlobalActions(?GroupedActions $actions): self
    {
        $this->globalActions = $actions;

        return $this;
    }

    public function withData(LengthAwarePaginator $data): self
    {
        $this->metadata['totalItems'] = $data->total();
        $this->metadata['pageCount'] = $data->lastPage();
        $this->metadata['pageNum'] = $data->currentPage();

        $data
            ->mapInto(TableRow::class)
            ->each(function (TableRow $tableRow): void {
                $this->data[] = $tableRow;
            });

        return $this;
    }
}
