<?php

namespace EventPortal\Tests\Feature\Actions;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Field\Models\Field;
use EventPortal\Domain\Field\Models\Section;
use EventPortal\Domain\Response\Actions\SaveToFields;
use EventPortal\Domain\Response\Models\Response;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class RespondToTest extends TestCase
{
    use DatabaseMigrations;

    /** @test **/
    public function can_respond_to_model()
    {
        /** @var SaveToFields $action */
        $action = app(SaveToFields::class);

        $event = factory(Event::class)->create();

        $section = factory(Field::class)
            ->states('Section')
            ->create([
                'label' => 'Key details',
                'model_id' => $event->id,
                'model_type' => get_class($event),
            ]);

        factory(Field::class)
            ->states('TextInput')
            ->create([
                'label' => 'Event name',
                'name' => 'event_name',
                'model_id' => $event->id,
                'model_type' => get_class($event),
                'section_id' => $section->id,
            ]);

        $action->execute($event, ['event_name' => 'Hello World!']);

        $this->assertEquals('Hello World!', Response::first()->value);
    }

    /** @test **/
    public function can_update_a_reponse()
    {
        $event = factory(Event::class)->create();

        $section = factory(Field::class)
            ->states('Section')
            ->create([
                'label' => 'Key details',
                'model_id' => $event->id,
                'model_type' => get_class($event),
            ]);

        $field = factory(Field::class)
            ->states('TextInput')
            ->create([
                'label' => 'Event name',
                'name' => 'event_name',
                'model_id' => $event->id,
                'model_type' => get_class($event),
                'section_id' => $section->id,
            ]);

        factory(Response::class)
            ->create([
                'field_id' => $field->id,
                'value' => 'Hello World!',
            ]);

        (new SaveToFields)->execute($event, ['event_name' => 'Goodbye World!']);

        $this->assertEquals('Goodbye World!', $field->response->value);
    }
}
