<?php

namespace EventPortal\Tests\Unit\Component;

use EventPortal\Domain\Component\Dropdown\MultiSelect;
use EventPortal\Domain\Component\Dropdown\Select;
use EventPortal\Domain\Component\Facades\Input;
use EventPortal\Domain\Component\Input\PasswordInput;
use EventPortal\Domain\Component\Input\TextArea;
use EventPortal\Domain\Component\Input\TextInput;
use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Component\Selection\Checkbox;
use EventPortal\Domain\Component\Selection\RadioButtons;
use EventPortal\Domain\Component\Selection\SlideToggle;
use EventPortal\Domain\Field\Models\Field;
use EventPortal\Tests\TestCase;

class InputTest extends TestCase
{
    /** @test */
    public function can_make_text_input()
    {
        $field = factory(Field::class)->states(['without-model', 'TextInput'])->make();

        $component = Input::fromField($field);

        $this->assertInstanceOf(TextInput::class, $component);
    }

    /** @test */
    public function can_make_select()
    {
        $field = factory(Field::class)->states(['without-model', 'Select'])->make();

        $component = Input::fromField($field);

        $this->assertInstanceOf(Select::class, $component);
    }

    /** @test */
    public function can_make_radio_buttons()
    {
        $field = factory(Field::class)->states(['without-model', 'RadioButtons'])->make();

        $component = Input::fromField($field);

        $this->assertInstanceOf(RadioButtons::class, $component);
    }

    /** @test */
    public function can_make_password_input()
    {
        $field = factory(Field::class)->states(['without-model', 'PasswordInput'])->make();

        $component = Input::fromField($field);

        $this->assertInstanceOf(PasswordInput::class, $component);
    }

    /** @test */
    public function can_make_text_area()
    {
        $field = factory(Field::class)->states(['without-model', 'TextArea'])->make();

        $component = Input::fromField($field);

        $this->assertInstanceOf(TextArea::class, $component);
    }

    /** @test */
    public function can_make_multi_select()
    {
        $field = factory(Field::class)->states(['without-model', 'MultiSelect'])->make();

        $component = Input::fromField($field);

        $this->assertInstanceOf(MultiSelect::class, $component);
    }

    /** @test */
    public function can_make_checkbox()
    {
        $field = factory(Field::class)->states(['without-model', 'Checkbox'])->make();

        $component = Input::fromField($field);

        $this->assertInstanceOf(Checkbox::class, $component);
    }

    /** @test */
    public function can_make_slide_toggle()
    {
        $field = factory(Field::class)->states(['without-model', 'SlideToggle'])->make();

        $component = Input::fromField($field);

        $this->assertInstanceOf(SlideToggle::class, $component);
    }

    /** @test **/
    public function made_with_label()
    {
        $field = factory(Field::class)
            ->states(['without-model', 'TextInput'])
            ->make([
                'label' => 'Event name',
            ]);

        $component = Input::fromField($field);

        $this->assertEquals('Event name', $component->label);
    }

    /** @test **/
    public function made_with_placeholder()
    {
        $field = factory(Field::class)
            ->states(['without-model', 'TextInput'])
            ->make([
                'data' => ['placeholder' => 'Hello World'],
            ]);

        $component = Input::fromField($field);

        $this->assertEquals('Hello World', $component->placeholder);
    }

    /** @test **/
    public function made_with_clearable()
    {
        $field = factory(Field::class)
            ->states(['without-model', 'TextInput'])
            ->make([
                'data' => ['clearable' => true],
            ]);

        $component = Input::fromField($field);

        $this->assertTrue($component->clearable);
    }

    /** @test **/
    public function made_with_classes()
    {
        $field = factory(Field::class)
            ->states(['without-model', 'TextInput'])
            ->make([
                'data' => ['classes' => ['col-6', 'no-margin']],
            ]);

        $component = Input::fromField($field);

        $this->assertEquals('col-6', $component->classes[0]);
        $this->assertEquals('no-margin', $component->classes[1]);
    }

    /** @test **/
    public function made_with_validation()
    {
        $field = factory(Field::class)
            ->states(['without-model', 'TextInput'])
            ->make([
                'data' => ['validation' => ['required', 'email']],
            ]);

        $component = Input::fromField($field);

        $this->assertEquals('required', $component->validation[0]);
        $this->assertEquals('email', $component->validation[1]);
        $this->assertTrue($component->required);
    }

    /** @test **/
    public function made_with_options()
    {
        $field = factory(Field::class)
            ->states(['without-model', 'Select'])
            ->make([
                'data' => ['options' => [
                    Option::make('Yes'),
                    Option::make('No')
                ]],
            ]);

        $component = Input::fromField($field);

        $expected = [
            ['label' => 'Yes', 'value' => 'yes'],
            ['label' => 'No', 'value' => 'no'],
        ];

        $this->assertEquals($expected, $component->options);
    }

    /** @test */
    public function is_not_made_if_there_are_no_options()
    {
        $field = factory(Field::class)
            ->states(['without-model', 'Select'])
            ->make();

        $component = Input::fromField($field);

        $this->assertEquals([], $component->options);
    }
}
