<?php

namespace EventPortal\Tests\Unit\Util;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Field\Enums\FieldType;
use EventPortal\Domain\Field\Models\Field;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Util\ValidationRules;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class ValidationRulesTest extends TestCase
{
    use DatabaseMigrations;

    /** @test **/
    public function can_get_validation_rules_for_form_with_model()
    {
        $event = factory(Event::class)->create();

        $section = factory(Field::class)->states('Section')->create(['model_id' => $event->id]);

        factory(Field::class)->create([
            'name' => 'event_name',
            'section_id' => $section->id,
            'model_id' => $event->id,
            'data' => ['validation' => ['required']],
        ]);

        $form = Form::make($event);

        $actual = ValidationRules::forForm($form);

        $this->assertEquals(['event_name' => ['required']], $actual);
    }

    /** @test */
    public function can_get_validation_rules_for_form_from_config()
    {
        $config = [
            'type' => Event::class,
            'label' => 'Event',
            'content' => [
                [
                    'label' => 'Key details',
                    'component' => FieldType::Section()->getValue(),
                    'children' => [
                        [
                            'component' => FieldType::TextInput()->getValue(),
                            'name' => 'event_name',
                            'label' => 'Event name',
                            'classes' => ['col-6'],
                            'validation' => [
                                'required',
                            ],
                            'placeholder' => 'E.g. Congress meeting',
                        ],
                    ],
                ],
            ],
        ];

        config()->set('defaults.event.fields', $config);

        $form = Form::make(Event::class);

        $actual = ValidationRules::forForm($form);

        $this->assertEquals(['event_name' => ['required']], $actual);
    }
}
